pub enum PaymentPolicy {
ReceivesDisabled,
}Expand description
A restriction on the payments the gateway performs on behalf of a federation’s clients.
Variants
ReceivesDisabled
Do not accept incoming Lightning payments: refuse to create invoices and fail back the payments of invoices that were already issued.